@@ -35,8 +35,6 @@ SEXP R_H5Tenum_nameof(SEXP R_type, SEXP R_value, SEXP R_name, SEXP R_size);
 SEXP R_H5Tenum_valueof(SEXP R_type, SEXP R_name, SEXP R_value, SEXP _dupl_value);
 /* H5_DLL htri_t H5Tequal(hid_t type1_id, hid_t type2_id); */
 SEXP R_H5Tequal(SEXP R_type1_id, SEXP R_type2_id);
-/* H5_DLL herr_t H5Tflush(hid_t type_id); */
-SEXP R_H5Tflush(SEXP R_type_id);
 /* H5_DLL int H5Tget_array_dims2(hid_t type_id, hsize_t dims[]); */
 SEXP R_H5Tget_array_dims2(SEXP R_type_id, SEXP R_dims);
 /* H5_DLL int H5Tget_array_ndims(hid_t type_id); */
@@ -99,8 +97,6 @@ SEXP R_H5Tlock(SEXP R_type_id);
 SEXP R_H5Topen2(SEXP R_loc_id, SEXP R_name, SEXP R_tapl_id);
 /* H5_DLL herr_t H5Tpack(hid_t type_id); */
 SEXP R_H5Tpack(SEXP R_type_id);
-/* H5_DLL herr_t H5Trefresh(hid_t type_id); */
-SEXP R_H5Trefresh(SEXP R_type_id);
 /* H5_DLL herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset); */
 SEXP R_H5Tset_cset(SEXP R_type_id, SEXP R_cset);
 /* H5_DLL herr_t H5Tset_ebias(hid_t type_id, size_t ebias); */
